aboutsummaryrefslogtreecommitdiffstats
path: root/backends/smv/test_cells.sh
diff options
context:
space:
mode:
Diffstat (limited to 'backends/smv/test_cells.sh')
-rw-r--r--backends/smv/test_cells.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/backends/smv/test_cells.sh b/backends/smv/test_cells.sh
index 63de465c0..ae832ce00 100644
--- a/backends/smv/test_cells.sh
+++ b/backends/smv/test_cells.sh
@@ -7,8 +7,8 @@ mkdir -p test_cells.tmp
cd test_cells.tmp
# don't test $mul to reduce runtime
-# don't test $div and $mod to reduce runtime and avoid "div by zero" message
-../../../yosys -p 'test_cell -n 5 -w test all /$alu /$fa /$lcu /$lut /$macc /$mul /$div /$mod'
+# don't test $div/$mod/$modfloor to reduce runtime and avoid "div by zero" message
+../../../yosys -p 'test_cell -n 5 -w test all /$alu /$fa /$lcu /$lut /$macc /$mul /$div /$mod /$modfloor'
cat > template.txt << "EOT"
%module main